#
# spec file for package python-Flask-Login
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Flask-Login
Version:        0.6.3
Release:        2.1
Summary:        User session management for Flask
License:        MIT
URL:            https://github.com/maxcountryman/flask-login
Source:         https://files.pythonhosted.org/packages/source/F/Flask-Login/Flask-Login-%{version}.tar.gz
# PATCH-FIX-UPSTREAM Based on gh#maxcountryman/flask-login#815
Patch0:         do-not-use-datetime-utcnow.patch
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module asgiref >= 3.2}
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module semantic_version}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask
BuildArch:      noarch
%python_subpackages

%description
Flask-Login provides user session management for Flask. It handles the common
tasks of logging in, logging out, and remembering your users'
sessions over extended periods of time.

Flask-Login is not bound to any particular database system or permissions
model. The only requirement is that your user objects implement a few
methods, and that you provide a callback to the extension capable of
loading users from their ID.

%prep
%autosetup -p1 -n Flask-Login-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/flask_login
%{python_sitelib}/[Ff]lask[_-][Ll]ogin-%{version}.dist-info

%changelog
* Tue May  6 2025 Steve Kowalik <steven.kowalik@suse.com>
- Actually run the testsuite.
- Switch to pyproject macros.
- Support both uppercased and normalized metadata directory names.
- Add patch do-not-use-datetime-utcnow.patch:
  * Do not use deprecated datetime.utcnow() function.
* Sun Sep  8 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.3:
  * Compatibility with Flask 3 and Werkzeug 3. #813
- drop 0001-fix-avoid-Deprecated-werkzeug.urls.url_decode.patch
  (upstream)
* Fri Dec 29 2023 Antonio Larrosa <alarrosa@suse.com>
- Use %%{?sle15_python_module_pythons}
* Mon Oct 30 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch from upstream to fix compatibility with Werkzeug 3.0.x
  where werkzeug.urls removed url_decode/url_encode:
  * 0001-fix-avoid-Deprecated-werkzeug.urls.url_decode.patch
* Fri Sep 30 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.6.2:
  * Fix compatibility with Werkzeug 2.2 and Flask 2.2. #691
  * Revert change to expand_login_view that attempted to preserve a dynamic
    subdomain value. Such values should be handled using
    app.url_value_preprocessor and app.url_defaults. #691
  * Ensure deprecation warnings are present for deprecated features that will be removed in the next feature release.
    + Use request_loader instead of header_loader.
    + Use user_loaded_from_request instead of user_loaded_from_header.
    + Use app.config["LOGIN_DISABLED"] instead of _login_disabled.
    + Use init_app instead of setup_app
* Sun Jun  5 2022 Arun Persaud <arun@gmx.de>
- update to version 0.6.1:
  * Only preserve subdomain or host view args in unauthorized redirect
    [#663]
  * The new utility function login_remembered returns True if the
    current login is remembered across sessions. #654
  * Fix side effect potentially executing view twice for same
    request. #666
  * Clarify usage of FlaskLoginClient test client in docs. #668
* Sat Apr  9 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * require python >= 3.7
- update to version 0.6.0:
  * Drop support for Python 2.7, 3.5, and 3.6, which have all reached
    the end of their official support. #594, #638
  * The minimum supported version of Flask is 1.0.4, and Werkzeug is
    1.0.1. However, projects are advised to use the latest versions of
    both. #639
  * Only flash "needs_refresh_message" if value is set #464
  * Modify expand_login_view to allow for subdomain and host matching
    for login_view #462
  * Add accessors for request_loader and user_loader callback
    functions #472
  * Change "remember_me" cookie to match Werkzeug default value #488
  * Change "remember_me" cookie to HttpOnly, matching Flask session
    cookie #488
  * Add example for using unauthorized_handler #492
  * Fix assertEqual deprecation warning in pytest #518
  * Fix collections deprecation warning under Python 3.8 #525
  * Replace safe_str_cmp with hmac.compare_digest #585
  * Document REMEMBER_COOKIE_SAMESITE config #577
  * Revise setup.py to use README.md for long description #598
  * Various documentation corrections #484, #482, #487, #534
  * Fix from flask_login import * behavior, although note that import
  * is not usually a good pattern in code. #485
  * UserMixin.is_authenticated will return whatever is_active returns
    by default. This prevents inactive users from logging in. #486,
    [#530]
  * Session protection will only mark the session as not fresh if it's
    not already marked as such, avoiding modifying the session cookie
    unnecessarily. #612
* Sun Feb 16 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * remove python devel
  * be more specific in %%files section
- update to version 0.5.0:
  * New custom test client: `flask_login.FlaskLoginClient`.  You can
    use this to write clearer automated tests. #431
  * Prefix authenticated user_id, remember, and remember_seconds in
    Flask Session with underscores to prevent accidental usage in
    application code. #470
  * Simplify user loading. #378
  * Various documentation improvements. #393, #394, #397, #417
  * Set session ID when setting next. #403
  * Clear session identifier on logout. #404
  * Ensure use of a safe and up-to-date version of Flask.
  * Drop support of Python versions: 2.6, 3.3, 3.4 #450
* Sun Dec  3 2017 arun@gmx.de
- update to version 0.4.1:
  * New config option USE_SESSION_FOR_NEXT to enable storing next url
    in session instead of url. #330
  * Accept int seconds along with timedelta for
    REMEMBER_COOKIE_DURATION. #370
  * New config option FORCE_HOST_FOR_REDIRECTS to force host for
    redirects. #371
* Fri Sep  8 2017 toddrme2178@gmail.com
- Initial version
